#!/bin/sh
#
# Generate and install public/private ssh key pair
#   the key will be hardened to disable port forwarding 
#
#   Sat Nov 25 2006, Leo Zimmermann
#

# default remote user
RUSER=root

# default target architecture (Thecus N2100 SSH Module, Mac OS X)
RKEYFILELOC=Thecus
#RKEYFILELOC=MacOSX

# default (ssh) server name or ip address (if not set script will query server name)
#TARGETHOST=thecusgrey

#  ---- ---- ---- ---- END OF USER CONFIGURABLE SECTION ---- ---- ----  ----

echo; echo "first, let's generate a new key pair"
echo "  (hit enter if you do not want to protect key by password)"
ssh-keygen -t rsa -f ~/.ssh/passkey

# do we have a (default) remote user name?
if [ ! ${RUSER} ]; then
  echo -n "remote user name (user on ssh server)? "; read RUSER
fi

# do we have a hostname/ip of the machine running the ssh server?
if [ ! ${TARGETHOST} ]; then
  echo -n "hostname or local ip address of ssh server? "; read TARGETHOST
fi

# rename private key to match target hostname
mv ~/.ssh/passkey ~/.ssh/passkey-${TARGETHOST}

echo "now, harden public key to disable port forwarding"
echo -n "no-port-forwarding,no-X11-forwarding,no-agent-forwarding " > /tmp/passkey.pub.edit
cat ~/.ssh/passkey.pub >> /tmp/passkey.pub.edit
mv /tmp/passkey.pub.edit ~/.ssh/passkey-${TARGETHOST}.pub

# determine file location on remote machine to store key
if [ ${RKEYFILELOC} == "Thecus" ]; then
  RKEYFILE=/raid/module/SSH/sshkeys/authorized_keys2
else
  RKEYFILE=/Users/${RUSER}/.ssh/authorized_keys2
fi

echo "Copy hardened public key to ${TARGETHOST} (requires ${RUSER} passwd)"
cat ~/.ssh/passkey-${TARGETHOST}.pub | ssh ${RUSER}@${TARGETHOST} "sh -c \"cat - >>${RKEYFILE}\""

echo; echo "key for user ${RUSER} has been stored here: ~/.ssh/passkey-${TARGETHOST}"
