#!/bin/sh
#
# backup using rsync over secured tunnel (ssh)
#   uses hardened public ssh key to allow password less backups
#
#   Thu Nov 2 2006, Leo Zimmermann
#
# Based on Brice Burgess (bhb@iceburg.net) script rbackup.sh
#

# Directories to backup. Separate with a space. Exclude trailing slash!
#RSOURCES="/Users/shareme/Pictures /Users/shareme/Music /Users/shareme/Documents"

# IP or FQDN of Remote Machine
#RMACHINE=thecusgrey

# Remote username
RUSER=root

# Location of passphraseless ssh keyfile
RKEY=$HOME/.ssh/secrsync

# This is where your backup(s) will be stored. Exclude trailing slash!
RTARGET="/raid/Backup"

# Your EXCLUDE_FILE tells rsync what NOT to backup. Leave it unchanged, missing or
# empty if you want to backup all files in your SOURCES. If performing a FULL SYSTEM BACKUP,
# ie. Your SOURCES is set to "/", you will need to make use of EXCLUDE_FILE. The file should
# contain directories and filenames, one per line.
#
# An example of a EXCLUDE_FILE would be:
# /proc/
# /tmp/
# /mnt/
# *.SOME_KIND_OF_FILE
EXCLUDE_FILE="/path/to/your/exclude_file.txt"

# specify backup options for rsync
#RSYNCOPTIONS="--recursive --times -pog --links --delete"
RSYNCOPTIONS="--recursive --times -pog --links"

# Comment out to disable talkative mode
VERBOSE="--progress --stats"

#  ---- ---- ---- ---- END OF USER CONFIGURABLE SECTION ---- ---- ----  ----

# do we have a IP or FQDN of the Remote Machine?
if [ ! ${RMACHINE} ]; then
  echo -n "hostname or local ip address of remote server? "; read RMACHINE
fi

# do we know the backup source(s)?
if [ ! ${RSOURCES} ]; then
  echo -n "source directory to be backed up? "; read RSOURCES
fi

# complete keyfile name
RKEY=${RKEY}-${RMACHINE}

if [ ! -f ${RKEY} ]; then
  echo "Couldn't find ssh keyfile!"
  echo "Exiting..."
  exit 2
fi

if ! ssh -i ${RKEY} ${RUSER}@${RMACHINE} "test -x ${RTARGET}"; then
  echo "Target directory on remote machine doesn't exist or bad permissions."
  echo "Exiting..."
  exit 2
fi

echo "Verifying Sources..."
for source in ${RSOURCES}; do
    echo "Checking $source..."
    if [ ! -x $source ]; then
     echo "Error with $source!"
     echo "Directory either does not exist, or you do not have proper permissions."
     exit 2
   fi
done

if [ -f $EXCLUDE_FILE ]; then
EXCLUDE="--exclude-from=${EXCLUDE_FILE}"
fi

echo "Sources verified. Running rsync..."
for source in ${RSOURCES}; do

  # Create directories in $RTARGET to mimick source directory hiearchy
  if ! ssh -i ${RKEY} ${RUSER}@${RMACHINE} "test -d ${RTARGET}/$source"; then
    ssh -i ${RKEY} ${RUSER}@${RMACHINE} "mkdir -p ${RTARGET}/$source"
  fi

  rsync ${VERBOSE} ${EXCLUDE} ${RSYNCOPTIONS} -e "ssh -i $RKEY" $source/ ${RUSER}@${RMACHINE}:${RTARGET}/$source/

done

exit 0
