#!/bin/sh
#
# Generate and install public/private ssh key pair
#   the key will be hardened to disable port forwarding 
#
#   Wed Mar 18 2008, Leo Zimmermann
#

# default (ssh) server name or ip address (if not set script will query server name)
#TARGETHOST=thecusgrey

#  ---- ---- ---- ---- END OF USER CONFIGURABLE SECTION ---- ---- ----  ----

echo; echo "First, let's generate a new key pair"
echo "  (hit enter, we do not want to protect the key by a password)"
ssh-keygen -t rsa -f ~/.ssh/secrsync

# do we have a hostname/ip of the machine running the ssh server?
if [ ! ${TARGETHOST} ]; then
  echo -n "hostname or local ip address of ssh server? "; read TARGETHOST
fi

# rename private key to match target hostname
mv ~/.ssh/secrsync ~/.ssh/secrsync-${TARGETHOST}

# create a rsync wrapper script (to be used by the hardened key)
cat >> ./validate-rsync.sh <<EOF
#!/bin/sh
#
date=\`date\`
case "\$SSH_ORIGINAL_COMMAND" in
*\&*)
  echo "Rejected"
  echo "\$date: rejected command \$SSH_ORIGINAL_COMMAND" >> /root/backup.log
  ;;
*\;*)
  echo "Rejected"
  echo "\$date: rejected command \$SSH_ORIGINAL_COMMAND" >> /root/backup.log
  ;;
rsync*)
  echo "\$date: accepted command \$SSH_ORIGINAL_COMMAND" >> /root/backup.log
  \$SSH_ORIGINAL_COMMAND
  ;;
mkdir*)
  echo "\$date: accepted command \$SSH_ORIGINAL_COMMAND" >> /root/backup.log
  \$SSH_ORIGINAL_COMMAND
  ;;
test*)
  echo "\$date: accepted command \$SSH_ORIGINAL_COMMAND" >> /root/backup.log
  \$SSH_ORIGINAL_COMMAND
  ;;
*)
  echo "Rejected"
  echo "\$date: rejected command \$SSH_ORIGINAL_COMMAND" >> /root/backup.log
  ;;
esac
EOF

echo; echo "Now, harden public key to only allow rsync"
echo -n "command=\"/raid/module/SSH/sshkeys/validate-rsync.sh\",no-port-forwarding,no-X11-forwarding,no-agent-forwarding " > /tmp/secrsync.pub.edit
cat ~/.ssh/secrsync.pub >> /tmp/secrsync.pub.edit
mv /tmp/secrsync.pub.edit ~/.ssh/secrsync-${TARGETHOST}.pub

echo; echo "Copy rsync wrapper to ${TARGETHOST} (requires root passwd)"
cat ./validate-rsync.sh | ssh root@${TARGETHOST} 'sh -c "cat - >/raid/module/SSH/sshkeys/validate-rsync.sh"; chmod 0755 /raid/module/SSH/sshkeys/validate-rsync.sh'

# get rid of local ./validate-rsync.sh
rm -f ./validate-rsync.sh 

echo; echo "Copy hardened public key to ${TARGETHOST} (requires root passwd)"
cat ~/.ssh/secrsync-${TARGETHOST}.pub | ssh root@${TARGETHOST} 'sh -c "cat - >>/raid/module/SSH/sshkeys/authorized_keys2"'

echo; echo "We're done here!"
